/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.dao;

import java.util.List;

import org.springframework.jdbc.support.rowset.SqlRowSet;

/**
 * 
 * @author Narine Ghochikyan
 *
 */
public interface SqlPlusDao {
	/**
	 * Executes update for each given query
	 * @param queries queries to be executed
	 * @return total number of rows affected
	 */
	int update(String[] queries);
	/**
	 * Executes query with given fetch size 
	 * @param query query to be executed
	 * @param fetchSize fetch size
	 * @return result row set
	 */
	SqlRowSet queryForRowSet(String query, int fetchSize);
	/**
     * performs the batch update
     *
     * @param values             the values to update
     * @param sql                update sql
     * @return update count for each update ran (one update per value in values)
     */
	Object batchUpdate(List values, String sql, boolean detailedOutput);
	 /**
     * Performs the batch updates based on SqlRowSet content
     *
     * @param sqlRowSet          data source
     * @param sql                update sql
     * @param batchSize          size of single batch update input
     * @return update count for each update ran (one update per row in sqlRowSet)
     */
	Object batchUpdate(SqlRowSet sqlRowSet, String sql, int batchSize, boolean detailedOutput);
}
