/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.impl.iterator;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.NoSuchElementException;
import org.springframework.jdbc.support.rowset.SqlRowSet;

/**
 *
 * @author Tommy Barker
 */
public class SqlIterator implements Iterator<Map<String, Object>> {

    private SqlRowSet sqlRowSet;
    private String[] columnNames;
    private boolean hasNext;

    public SqlIterator(SqlRowSet sqlRowSet) {
        this.sqlRowSet = sqlRowSet;
        this.columnNames = sqlRowSet.getMetaData().getColumnNames();
        this.hasNext = sqlRowSet.next();
    }

    public boolean hasNext() {
        return hasNext;
    }

    public Map<String, Object> next() {
        if (hasNext) {
            Map<String, Object> result = new HashMap<String, Object>();
            for (String columnName : columnNames) {
                result.put(columnName, sqlRowSet.getObject(columnName));
            }
            hasNext = sqlRowSet.next();
            return result;
        } else {
            throw new NoSuchElementException();
        }
    }

    public void remove() {
        throw new UnsupportedOperationException();
    }
}
