/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package metridoc.registry;

import org.apache.camel.impl.SimpleRegistry;
import org.apache.camel.spi.Registry;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * Code from camel's {@link SimpleRegistry} was copied and repurposed so a hash can be provided that can be 
 * manipulated outside of the camel registry
 *
 * @author Tommy Barker
 */
public class MetridocSimpleRegistry implements Registry{
    private final Map<String, Object> services;
    public static final String CAMEL_CONTEXT = "camelContext";
    public static final String CAMEL_REGISTRY = "camelRegistry";
    public static final String STOP_CAMEL = "stopCamel";
    public static final String URIS_TO_CHECK = "urisToCheck";

    public MetridocSimpleRegistry(Map<String, Object> services) {
        this.services = services;
    }

    @Override
    public Object lookup(String name) {
        return services.get(name);
    }

    @Override
    public <T> T lookup(String name, Class<T> type) {
        Object o = lookup(name);
        return type.cast(o);
    }

    @Override
    public <T> Map<String, T> lookupByType(Class<T> type) {
        Map<String, T> result = new HashMap<String, T>();
        for (Map.Entry<String, Object> entry : services.entrySet()) {
            if (type.isInstance(entry.getValue())) {
                result.put(entry.getKey(), type.cast(entry.getValue()));
            }
        }
        return result;
    }
}
